==> pointtree-0.0.0.tar.gz: pointtree-0.0.0/README.md <==
# PointTree

## A Python Package for Individual Tree Segmentation in 3D Point Clouds.

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![CI](https://github.com/ai4trees/pointtree/actions/workflows/code-quality-main.yml/badge.svg)](https://github.com/ai4trees/pointtree/actions/workflows/code-quality-main.yml)
![coverage](coverage.svg)

The package contains the official source code of the paper ["Burmeister, Josafat-Mattias, et al. "Tree Instance Segmentation in Urban 3D Point Clouds Using a Coarse-to-Fine Algorithm Based on Semantic Segmentation." ISPRS Annals of the Photogrammetry, Remote Sensing and Spatial Information Sciences 10 (2024): 79-86.](https://isprs-annals.copernicus.org/articles/X-4-W5-2024/79/2024/isprs-annals-X-4-W5-2024-79-2024.pdf)

### Package Documentation

The documentation of our package is available [here](https://ai4trees.github.io/pointtree/).

### Project Setup

The setup of our package is described in the [documentation](https://ai4trees.github.io/pointtree/#get-started).

### How to Cite

If you use our code, please consider citing our paper:

```
@article{Burmeister_Tree_Instance_Segmentation_2024,
author = {Burmeister, Josafat-Mattias and Richter, Rico and Reder, Stefan and Mund, Jan-Peter and Döllner, Jürgen},
doi = {10.5194/isprs-annals-X-4-W5-2024-79-2024},
journal = {ISPRS Annals of the Photogrammetry, Remote Sensing and Spatial Information Sciences},
pages = {79--86},
title = {{Tree Instance Segmentation in Urban 3D Point Clouds Using a Coarse-to-Fine Algorithm Based on Semantic Segmentation}},
volume = {X-4/W5-2024},
year = {2024}
}
```

==> pointtree-0.1.0.tar.gz: pointtree-0.1.0/README.md <==
<img src="https://github.com/ai4trees/pointtree/blob/main/docs/assets/pointtree-logo-color.png" alt="pointtree" width="300" height="100">

## A Python Package for Tree Instance Segmentation in 3D Point Clouds.

![pypi-image](https://badge.fury.io/py/pointtree.svg)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![CI](https://github.com/ai4trees/pointtree/actions/workflows/code-quality-main.yml/badge.svg)](https://github.com/ai4trees/pointtree/actions/workflows/code-quality-main.yml)
[![coverage](https://codecov.io/gh/ai4trees/pointtree/branch/main/graph/badge.svg)](https://codecov.io/github/ai4trees/pointtree?branch=main)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pointtree)

The package contains the official source code of the paper ["Burmeister, Josafat-Mattias, et al. "Tree Instance Segmentation in Urban 3D Point Clouds Using a Coarse-to-Fine Algorithm Based on Semantic Segmentation." ISPRS Annals of the Photogrammetry, Remote Sensing and Spatial Information Sciences 10 (2024): 79-86.](https://isprs-annals.copernicus.org/articles/X-4-W5-2024/79/2024/isprs-annals-X-4-W5-2024-79-2024.pdf)

### Package Documentation

The documentation of our package is available [here](https://ai4trees.github.io/pointtree/stable).

### Project Setup

The setup of our package is described in the [documentation](https://ai4trees.github.io/pointtree/stable#get-started).

### How to Cite

If you use our code, please consider citing our paper:

```
@article{Burmeister_Tree_Instance_Segmentation_2024,
author = {Burmeister, Josafat-Mattias and Richter, Rico and Reder, Stefan and Mund, Jan-Peter and Döllner, Jürgen},
doi = {10.5194/isprs-annals-X-4-W5-2024-79-2024},
journal = {ISPRS Annals of the Photogrammetry, Remote Sensing and Spatial Information Sciences},
pages = {79--86},
title = {{Tree Instance Segmentation in Urban 3D Point Clouds Using a Coarse-to-Fine Algorithm Based on Semantic Segmentation}},
volume = {X-4/W5-2024},
year = {2024}
}
```
